@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-# Copyright (c) 2014-2018 Michael Hirsch, Ph.D.
 """
 PyMap3D provides coordinate transforms and geodesy functions with a similar API
 to the Matlab Mapping Toolbox, but was of course independently derived.
@@ -35,7 +33,17 @@ from .aer import ecef2aer, aer2ecef, geodetic2aer, aer2geodetic
 from .ellipsoid import Ellipsoid
 from .enu import enu2geodetic, geodetic2enu, aer2enu, enu2aer
 from .ned import ned2ecef, ned2geodetic, geodetic2ned, ecef2nedv, ned2aer, aer2ned, ecef2ned
-from .ecef import geodetic2ecef, ecef2geodetic, eci2geodetic, geodetic2eci, ecef2enuv, enu2ecef, ecef2enu, enu2uvw, uvw2enu
+from .ecef import (
+    geodetic2ecef,
+    ecef2geodetic,
+    eci2geodetic,
+    geodetic2eci,
+    ecef2enuv,
+    enu2ecef,
+    ecef2enu,
+    enu2uvw,
+    uvw2enu,
+)
 from .sidereal import datetime2sidereal, greenwichsrt
 from .latitude import (
     geod2geoc,
