@@ -1,4 +1,6 @@
 """ transforms involving AER: azimuth, elevation, slant range"""
+
+from __future__ import annotations
 import typing
 from datetime import datetime
 
@@ -8,25 +10,25 @@ from .ellipsoid import Ellipsoid
 
 try:
     from .eci import eci2ecef, ecef2eci
+    from numpy import ndarray
 except ImportError:
     eci2ecef = ecef2eci = None
+    ndarray = typing.Any  # type: ignore
+
 
 __all__ = ["aer2ecef", "ecef2aer", "geodetic2aer", "aer2geodetic", "eci2aer", "aer2eci"]
 
-if typing.TYPE_CHECKING:
-    from numpy import ndarray
-
 
 def ecef2aer(
-    x: "ndarray",
-    y: "ndarray",
-    z: "ndarray",
-    lat0: "ndarray",
-    lon0: "ndarray",
-    h0: "ndarray",
+    x: float | ndarray,
+    y: float | ndarray,
+    z: float | ndarray,
+    lat0: float,
+    lon0: float,
+    h0: float,
     ell: Ellipsoid = None,
     deg: bool = True,
-) -> typing.Tuple["ndarray", "ndarray", "ndarray"]:
+) -> tuple[float, float, float]:
     """
     compute azimuth, elevation and slant range from an Observer to a Point with ECEF coordinates.
 
@@ -35,17 +37,17 @@ def ecef2aer(
     Parameters
     ----------
 
-    x : "ndarray"
+    x : float
         ECEF x coordinate (meters)
-    y : "ndarray"
+    y : float
         ECEF y coordinate (meters)
-    z : "ndarray"
+    z : float
         ECEF z coordinate (meters)
-    lat0 : "ndarray"
+    lat0 : float
         Observer geodetic latitude
-    lon0 : "ndarray"
+    lon0 : float
         Observer geodetic longitude
-    h0 : "ndarray"
+    h0 : float
          observer altitude above geodetic ellipsoid (meters)
     ell : Ellipsoid, optional
         reference ellipsoid
@@ -54,11 +56,11 @@ def ecef2aer(
 
     Returns
     -------
-    az : "ndarray"
+    az : float
          azimuth to target
-    el : "ndarray"
+    el : float
          elevation to target
-    srange : "ndarray"
+    srange : float
          slant range [meters]
     """
     xEast, yNorth, zUp = ecef2enu(x, y, z, lat0, lon0, h0, ell, deg=deg)
@@ -67,15 +69,15 @@ def ecef2aer(
 
 
 def geodetic2aer(
-    lat: "ndarray",
-    lon: "ndarray",
-    h: "ndarray",
-    lat0: "ndarray",
-    lon0: "ndarray",
-    h0: "ndarray",
+    lat: float,
+    lon: float,
+    h: float,
+    lat0: float,
+    lon0: float,
+    h0: float,
     ell: Ellipsoid = None,
     deg: bool = True,
-) -> typing.Tuple["ndarray", "ndarray", "ndarray"]:
+) -> tuple[float, float, float]:
     """
     gives azimuth, elevation and slant range from an Observer to a Point with geodetic coordinates.
 
@@ -83,17 +85,17 @@ def geodetic2aer(
     Parameters
     ----------
 
-    lat : "ndarray"
+    lat : float
         target geodetic latitude
-    lon : "ndarray"
+    lon : float
         target geodetic longitude
-    h : "ndarray"
+    h : float
         target altitude above geodetic ellipsoid (meters)
-    lat0 : "ndarray"
+    lat0 : float
         Observer geodetic latitude
-    lon0 : "ndarray"
+    lon0 : float
         Observer geodetic longitude
-    h0 : "ndarray"
+    h0 : float
          observer altitude above geodetic ellipsoid (meters)
     ell : Ellipsoid, optional
           reference ellipsoid
@@ -102,11 +104,11 @@ def geodetic2aer(
 
     Returns
     -------
-    az : "ndarray"
+    az : float
          azimuth
-    el : "ndarray"
+    el : float
          elevation
-    srange : "ndarray"
+    srange : float
          slant range [meters]
     """
     e, n, u = geodetic2enu(lat, lon, h, lat0, lon0, h0, ell, deg=deg)
@@ -115,32 +117,32 @@ def geodetic2aer(
 
 
 def aer2geodetic(
-    az: "ndarray",
-    el: "ndarray",
-    srange: "ndarray",
-    lat0: "ndarray",
-    lon0: "ndarray",
-    h0: "ndarray",
+    az: float,
+    el: float,
+    srange: float,
+    lat0: float,
+    lon0: float,
+    h0: float,
     ell: Ellipsoid = None,
     deg: bool = True,
-) -> typing.Tuple["ndarray", "ndarray", "ndarray"]:
+) -> tuple[float | ndarray, float | ndarray, float | ndarray]:
     """
     gives geodetic coordinates of a point with az, el, range
     from an observer at lat0, lon0, h0
 
     Parameters
     ----------
-    az : "ndarray"
+    az : float
          azimuth to target
-    el : "ndarray"
+    el : float
          elevation to target
-    srange : "ndarray"
+    srange : float
          slant range [meters]
-    lat0 : "ndarray"
+    lat0 : float
            Observer geodetic latitude
-    lon0 : "ndarray"
+    lon0 : float
            Observer geodetic longitude
-    h0 : "ndarray"
+    h0 : float
          observer altitude above geodetic ellipsoid (meters)
     ell : Ellipsoid, optional
           reference ellipsoid
@@ -152,11 +154,11 @@ def aer2geodetic(
 
     In reference ellipsoid system:
 
-    lat : "ndarray"
+    lat : float
           geodetic latitude
-    lon : "ndarray"
+    lon : float
           geodetic longitude
-    alt : "ndarray"
+    alt : float
           altitude above ellipsoid  (meters)
     """
     x, y, z = aer2ecef(az, el, srange, lat0, lon0, h0, ell=ell, deg=deg)
@@ -165,34 +167,34 @@ def aer2geodetic(
 
 
 def eci2aer(
-    x: "ndarray",
-    y: "ndarray",
-    z: "ndarray",
-    lat0: "ndarray",
-    lon0: "ndarray",
-    h0: "ndarray",
+    x: float,
+    y: float,
+    z: float,
+    lat0: float,
+    lon0: float,
+    h0: float,
     t: datetime,
     *,
     deg: bool = True,
     use_astropy: bool = True
-) -> typing.Tuple["ndarray", "ndarray", "ndarray"]:
+) -> tuple[float, float, float]:
     """
     takes Earth Centered Inertial x,y,z ECI coordinates of point and gives az, el, slant range from Observer
 
     Parameters
     ----------
 
-    x : "ndarray"
+    x : float
         ECI x-location [meters]
-    y : "ndarray"
+    y : float
         ECI y-location [meters]
-    z : "ndarray"
+    z : float
         ECI z-location [meters]
-    lat0 : "ndarray"
+    lat0 : float
            Observer geodetic latitude
-    lon0 : "ndarray"
+    lon0 : float
            Observer geodetic longitude
-    h0 : "ndarray"
+    h0 : float
          observer altitude above geodetic ellipsoid (meters)
     t : datetime.datetime
         Observation time
@@ -203,11 +205,11 @@ def eci2aer(
 
     Returns
     -------
-    az : "ndarray"
+    az : float
          azimuth to target
-    el : "ndarray"
+    el : float
          elevation to target
-    srange : "ndarray"
+    srange : float
          slant range [meters]
     """
     if eci2ecef is None:
@@ -219,34 +221,34 @@ def eci2aer(
 
 
 def aer2eci(
-    az: "ndarray",
-    el: "ndarray",
-    srange: "ndarray",
-    lat0: "ndarray",
-    lon0: "ndarray",
-    h0: "ndarray",
+    az: float,
+    el: float,
+    srange: float,
+    lat0: float,
+    lon0: float,
+    h0: float,
     t: datetime,
     ell=None,
     *,
     deg: bool = True,
     use_astropy: bool = True
-) -> typing.Tuple["ndarray", "ndarray", "ndarray"]:
+) -> tuple[float | ndarray, float | ndarray, float | ndarray]:
     """
     gives ECI of a point from an observer at az, el, slant range
 
     Parameters
     ----------
-    az : "ndarray"
+    az : float
          azimuth to target
-    el : "ndarray"
+    el : float
          elevation to target
-    srange : "ndarray"
+    srange : float
          slant range [meters]
-    lat0 : "ndarray"
+    lat0 : float
            Observer geodetic latitude
-    lon0 : "ndarray"
+    lon0 : float
            Observer geodetic longitude
-    h0 : "ndarray"
+    h0 : float
          observer altitude above geodetic ellipsoid (meters)
     t : datetime.datetime
         Observation time
@@ -262,11 +264,11 @@ def aer2eci(
 
     Earth Centered Inertial x,y,z
 
-    x : "ndarray"
+    x : float
         ECEF x coordinate (meters)
-    y : "ndarray"
+    y : float
         ECEF y coordinate (meters)
-    z : "ndarray"
+    z : float
         ECEF z coordinate (meters)
     """
     if ecef2eci is None:
@@ -278,31 +280,31 @@ def aer2eci(
 
 
 def aer2ecef(
-    az: "ndarray",
-    el: "ndarray",
-    srange: "ndarray",
-    lat0: "ndarray",
-    lon0: "ndarray",
-    alt0: "ndarray",
+    az: float,
+    el: float,
+    srange: float,
+    lat0: float,
+    lon0: float,
+    alt0: float,
     ell: Ellipsoid = None,
     deg: bool = True,
-) -> typing.Tuple["ndarray", "ndarray", "ndarray"]:
+) -> tuple[float, float, float]:
     """
     converts target azimuth, elevation, range from observer at lat0,lon0,alt0 to ECEF coordinates.
 
     Parameters
     ----------
-    az : "ndarray"
+    az : float
          azimuth to target
-    el : "ndarray"
+    el : float
          elevation to target
-    srange : "ndarray"
+    srange : float
          slant range [meters]
-    lat0 : "ndarray"
+    lat0 : float
            Observer geodetic latitude
-    lon0 : "ndarray"
+    lon0 : float
            Observer geodetic longitude
-    h0 : "ndarray"
+    h0 : float
          observer altitude above geodetic ellipsoid (meters)
     ell : Ellipsoid, optional
           reference ellipsoid
@@ -314,11 +316,11 @@ def aer2ecef(
 
     ECEF (Earth centered, Earth fixed)  x,y,z
 
-    x : "ndarray"
+    x : float
         ECEF x coordinate (meters)
-    y : "ndarray"
+    y : float
         ECEF y coordinate (meters)
-    z : "ndarray"
+    z : float
         ECEF z coordinate (meters)
 
 
