@@ -1,12 +1,14 @@
 """ transforms involving ENU East North Up """
+from __future__ import annotations
 import typing
 
 try:
-    from numpy import radians, sin, cos, hypot, arctan2 as atan2, degrees, pi, vectorize
+    from numpy import radians, sin, cos, hypot, arctan2 as atan2, degrees, pi, vectorize, ndarray
 except ImportError:
-    from math import radians, sin, cos, hypot, atan2, degrees, pi
+    from math import radians, sin, cos, hypot, atan2, degrees, pi  # type: ignore
 
     vectorize = None
+    ndarray = typing.Any  # type: ignore
 
 from .ecef import geodetic2ecef, ecef2geodetic, enu2ecef, uvw2enu
 from .ellipsoid import Ellipsoid
@@ -16,22 +18,21 @@ tau = 2 * pi
 
 __all__ = ["enu2aer", "aer2enu", "enu2geodetic", "geodetic2enu"]
 
-if typing.TYPE_CHECKING:
-    from numpy import ndarray
 
-
-def enu2aer(e: "ndarray", n: "ndarray", u: "ndarray", deg: bool = True) -> typing.Tuple["ndarray", "ndarray", "ndarray"]:
+def enu2aer(
+    e: float | ndarray, n: float | ndarray, u: float | ndarray, deg: bool = True
+) -> tuple[float, float, float]:
     """
     ENU to Azimuth, Elevation, Range
 
     Parameters
     ----------
 
-    e : "ndarray"
+    e : float
         ENU East coordinate (meters)
-    n : "ndarray"
+    n : float
         ENU North coordinate (meters)
-    u : "ndarray"
+    u : float
         ENU Up coordinate (meters)
     deg : bool, optional
         degrees input/output  (False: radians in/out)
@@ -39,13 +40,14 @@ def enu2aer(e: "ndarray", n: "ndarray", u: "ndarray", deg: bool = True) -> typin
     Results
     -------
 
-    azimuth : "ndarray"
+    azimuth : float
         azimuth to rarget
-    elevation : "ndarray"
+    elevation : float
         elevation to target
-    srange : "ndarray"
+    srange : float
         slant range [meters]
     """
+
     if vectorize is not None:
         fun = vectorize(enu2aer_point)
         az, el, rng = fun(e, n, u, deg)
@@ -54,7 +56,9 @@ def enu2aer(e: "ndarray", n: "ndarray", u: "ndarray", deg: bool = True) -> typin
         return enu2aer_point(e, n, u, deg)
 
 
-def enu2aer_point(e: "ndarray", n: "ndarray", u: "ndarray", deg: bool = True) -> typing.Tuple["ndarray", "ndarray", "ndarray"]:
+def enu2aer_point(
+    e: float | ndarray, n: float | ndarray, u: float | ndarray, deg: bool = True
+) -> tuple[float, float, float]:
 
     # 1 millimeter precision for singularity
 
@@ -77,7 +81,7 @@ def enu2aer_point(e: "ndarray", n: "ndarray", u: "ndarray", deg: bool = True) ->
     return az, elev, slantRange
 
 
-def aer2enu(az: "ndarray", el: "ndarray", srange: "ndarray", deg: bool = True) -> typing.Tuple["ndarray", "ndarray", "ndarray"]:
+def aer2enu(az: float, el: float, srange: float, deg: bool = True) -> tuple[float, float, float]:
     if vectorize is not None:
         fun = vectorize(aer2enu_point)
         e, n, u = fun(az, el, srange, deg)
@@ -86,7 +90,9 @@ def aer2enu(az: "ndarray", el: "ndarray", srange: "ndarray", deg: bool = True) -
         return aer2enu_point(az, el, srange, deg)
 
 
-def aer2enu_point(az: float, el: float, srange: float, deg: bool = True) -> typing.Tuple[float, float, float]:
+def aer2enu_point(
+    az: float, el: float, srange: float, deg: bool = True
+) -> tuple[float, float, float]:
     """
     Azimuth, Elevation, Slant range to target to East, North, Up
 
@@ -123,31 +129,31 @@ def aer2enu_point(az: float, el: float, srange: float, deg: bool = True) -> typi
 
 
 def enu2geodetic(
-    e: "ndarray",
-    n: "ndarray",
-    u: "ndarray",
-    lat0: "ndarray",
-    lon0: "ndarray",
-    h0: "ndarray",
+    e: float,
+    n: float,
+    u: float,
+    lat0: float,
+    lon0: float,
+    h0: float,
     ell: Ellipsoid = None,
     deg: bool = True,
-) -> typing.Tuple["ndarray", "ndarray", "ndarray"]:
+) -> tuple[float | ndarray, float | ndarray, float | ndarray]:
     """
     East, North, Up to target to geodetic coordinates
 
     Parameters
     ----------
-    e : "ndarray"
+    e : float
         East ENU coordinate (meters)
-    n : "ndarray"
+    n : float
         North ENU coordinate (meters)
-    u : "ndarray"
+    u : float
         Up ENU coordinate (meters)
-    lat0 : "ndarray"
+    lat0 : float
            Observer geodetic latitude
-    lon0 : "ndarray"
+    lon0 : float
            Observer geodetic longitude
-    h0 : "ndarray"
+    h0 : float
          observer altitude above geodetic ellipsoid (meters)
     ell : Ellipsoid, optional
           reference ellipsoid
@@ -157,11 +163,11 @@ def enu2geodetic(
 
     Results
     -------
-    lat : "ndarray"
+    lat : float
           geodetic latitude
-    lon : "ndarray"
+    lon : float
           geodetic longitude
-    alt : "ndarray"
+    alt : float
           altitude above ellipsoid  (meters)
     """
 
@@ -171,29 +177,29 @@ def enu2geodetic(
 
 
 def geodetic2enu(
-    lat: "ndarray",
-    lon: "ndarray",
-    h: "ndarray",
-    lat0: "ndarray",
-    lon0: "ndarray",
-    h0: "ndarray",
+    lat: float,
+    lon: float,
+    h: float,
+    lat0: float,
+    lon0: float,
+    h0: float,
     ell: Ellipsoid = None,
     deg: bool = True,
-) -> typing.Tuple["ndarray", "ndarray", "ndarray"]:
+) -> tuple[float, float, float]:
     """
     Parameters
     ----------
-    lat : "ndarray"
+    lat : float
           target geodetic latitude
-    lon : "ndarray"
+    lon : float
           target geodetic longitude
-    h : "ndarray"
+    h : float
           target altitude above ellipsoid  (meters)
-    lat0 : "ndarray"
+    lat0 : float
            Observer geodetic latitude
-    lon0 : "ndarray"
+    lon0 : float
            Observer geodetic longitude
-    h0 : "ndarray"
+    h0 : float
          observer altitude above geodetic ellipsoid (meters)
     ell : Ellipsoid, optional
           reference ellipsoid
@@ -203,11 +209,11 @@ def geodetic2enu(
 
     Results
     -------
-    e : "ndarray"
+    e : float
         East ENU
-    n : "ndarray"
+    n : float
         North ENU
-    u : "ndarray"
+    u : float
         Up ENU
     """
     x1, y1, z1 = geodetic2ecef(lat, lon, h, ell, deg=deg)
