@@ -1,18 +1,21 @@
 """ compute radii of auxiliary spheres"""
 
+from __future__ import annotations
 import typing
 
 try:
-    from numpy import radians, sin, cos, log, sqrt, degrees, asarray
+    from numpy import radians, sin, cos, log, sqrt, degrees, asarray, ndarray
 except ImportError:
-    from math import radians, sin, cos, log, sqrt, degrees
+    from math import radians, sin, cos, log, sqrt, degrees  # type: ignore
 
     asarray = None
+    ndarray = typing.Any  # type: ignore
 
 from .ellipsoid import Ellipsoid
 from .rcurve import rcurve_meridian, rcurve_transverse
 from .vincenty import vdist
 
+
 __all__ = [
     "rsphere_eqavol",
     "rsphere_authalic",
@@ -23,9 +26,6 @@ __all__ = [
     "rsphere_biaxial",
 ]
 
-if typing.TYPE_CHECKING:
-    from numpy import ndarray
-
 
 def rsphere_eqavol(ell: Ellipsoid = None) -> float:
     """computes the radius of the sphere with equal volume as the ellipsoid
@@ -94,16 +94,21 @@ def rsphere_rectifying(ell: Ellipsoid = None) -> float:
 
 
 def rsphere_euler(
-    lat1: "ndarray", lon1: "ndarray", lat2: "ndarray", lon2: "ndarray", ell: Ellipsoid = None, deg: bool = True
-) -> "ndarray":
+    lat1: float | ndarray,
+    lon1: float,
+    lat2: float | ndarray,
+    lon2: float,
+    ell: Ellipsoid = None,
+    deg: bool = True,
+) -> float:
     """computes the Euler radii of curvature at the midpoint of the
      great circle arc defined by the endpoints (lat1,lon1) and (lat2,lon2)
 
     Parameters
     ----------
-    lat1, lat2 : "ndarray"
+    lat1, lat2 : float
         geodetic latitudes (degrees)
-    lon1, lon2 : "ndarray"
+    lon1, lon2 : float
        geodetic longitudes (degrees)
     ell : Ellipsoid, optional
           reference ellipsoid
@@ -112,7 +117,7 @@ def rsphere_euler(
 
     Returns
     -------
-    radius: "ndarray"
+    radius: float
         radius of sphere
     """
     if not deg:
@@ -136,13 +141,15 @@ def rsphere_euler(
     return rho * nu / den
 
 
-def rsphere_curve(lat: "ndarray", ell: Ellipsoid = None, deg: bool = True, method: str = "mean") -> "ndarray":
+def rsphere_curve(
+    lat: float, ell: Ellipsoid = None, deg: bool = True, method: str = "mean"
+) -> float:
     """computes the arithmetic average of the transverse and meridional
     radii of curvature at a specified latitude point
 
     Parameters
     ----------
-    lat1 : "ndarray"
+    lat1 : float
         geodetic latitudes (degrees)
     ell : Ellipsoid, optional
           reference ellipsoid
@@ -153,7 +160,7 @@ def rsphere_curve(lat: "ndarray", ell: Ellipsoid = None, deg: bool = True, metho
 
     Returns
     -------
-    radius: "ndarray"
+    radius: float
         radius of sphere
     """
 
