@@ -44,7 +44,11 @@ def datetime2sidereal(time: datetime, lon_radians: float, *, use_astropy: bool =
         return [datetime2sidereal(t, lon_radians) for t in time]
 
     if use_astropy and Time is not None:
-        tsr = Time(time).sidereal_time(kind="apparent", longitude=Longitude(lon_radians, unit=u.radian)).radian
+        tsr = (
+            Time(time)
+            .sidereal_time(kind="apparent", longitude=Longitude(lon_radians, unit=u.radian))
+            .radian
+        )
     else:
         jd = juliandate(str2dt(time))
         # %% Greenwich Sidereal time RADIANS
@@ -116,7 +120,12 @@ def greenwichsrt(Jdate: float) -> float:
     tUT1 = (Jdate - 2451545.0) / 36525.0
 
     # Eqn. 3-47 p. 188
-    gmst_sec = 67310.54841 + (876600 * 3600 + 8640184.812866) * tUT1 + 0.093104 * tUT1 ** 2 - 6.2e-6 * tUT1 ** 3
+    gmst_sec = (
+        67310.54841
+        + (876600 * 3600 + 8640184.812866) * tUT1
+        + 0.093104 * tUT1 ** 2
+        - 6.2e-6 * tUT1 ** 3
+    )
 
     # 1/86400 and %(2*pi) implied by units of radians
     return gmst_sec * (2 * pi) / 86400.0 % (2 * pi)
